==> create-fly-1.21.8-6.0.8-2-sources.jar: com/zurrtum/create/content/logistics/item/filter/attribute/attributes/ItemNameAttribute.java <==
package com.zurrtum.create.content.logistics.item.filter.attribute.attributes;

import com.google.gson.JsonParseException;
import com.google.gson.JsonParser;
import com.mojang.serialization.Codec;
import com.mojang.serialization.JsonOps;
import com.mojang.serialization.MapCodec;
import com.zurrtum.create.AllItemAttributeTypes;
import com.zurrtum.create.content.logistics.item.filter.attribute.ItemAttribute;
import com.zurrtum.create.content.logistics.item.filter.attribute.ItemAttributeType;
import io.netty.buffer.ByteBuf;
import org.jetbrains.annotations.NotNull;

import java.util.ArrayList;
import java.util.List;
import java.util.Optional;
import net.minecraft.class_1799;
import net.minecraft.class_1937;
import net.minecraft.class_2561;
import net.minecraft.class_8824;
import net.minecraft.class_9129;
import net.minecraft.class_9135;
import net.minecraft.class_9139;
import net.minecraft.class_9334;

public record ItemNameAttribute(String itemName) implements ItemAttribute {
    public static final MapCodec<ItemNameAttribute> CODEC = Codec.STRING.xmap(ItemNameAttribute::new, ItemNameAttribute::itemName).fieldOf("value");

    public static final class_9139<ByteBuf, ItemNameAttribute> PACKET_CODEC = class_9135.field_48554.method_56432(
        ItemNameAttribute::new,
        ItemNameAttribute::itemName
    );

    private static String extractCustomName(class_1799 stack, class_1937 level) {
        if (stack.method_57826(class_9334.field_49631)) {
            try {
                String customName = stack.method_58695(class_9334.field_49631, class_2561.method_43473()).getString();
                Optional<class_2561> component = class_8824.field_46597.parse(
                    level.method_30349().method_57093(JsonOps.INSTANCE),
                    JsonParser.parseString(customName.isEmpty() ? "\"\"" : customName)
                ).result();
                if (component.isPresent()) {
                    return component.get().getString();
                }
            } catch (JsonParseException ignored) {
            }
        }
        return "";
    }

    @Override
    public boolean appliesTo(class_1799 itemStack, class_1937 level) {
        return extractCustomName(itemStack, level).equals(itemName);
    }

    @Override
    public String getTranslationKey() {
        return "has_name";
    }

    @Override
    public Object[] getTranslationParameters() {
        return new Object[]{itemName};
    }

    @Override
    public ItemAttributeType getType() {
        return AllItemAttributeTypes.HAS_NAME;
    }

    public static class Type implements ItemAttributeType {
        @Override
        public @NotNull ItemAttribute createAttribute() {
            return new ItemNameAttribute("dummy");
        }

        @Override
        public List<ItemAttribute> getAllAttributes(class_1799 stack, class_1937 level) {
            List<ItemAttribute> list = new ArrayList<>();

            String name = extractCustomName(stack, level);
            if (!name.isEmpty()) {
                list.add(new ItemNameAttribute(name));
            }

            return list;
        }

        @Override
        public MapCodec<? extends ItemAttribute> codec() {
            return CODEC;
        }

        @Override
        public class_9139<? super class_9129, ? extends ItemAttribute> packetCodec() {
            return PACKET_CODEC;
        }
    }
}

==> create-fly-1.21.11-6.0.8-2-sources.jar: com/zurrtum/create/content/logistics/item/filter/attribute/attributes/ItemNameAttribute.java <==
package com.zurrtum.create.content.logistics.item.filter.attribute.attributes;

import com.google.gson.JsonParseException;
import com.google.gson.JsonParser;
import com.mojang.serialization.Codec;
import com.mojang.serialization.JsonOps;
import com.mojang.serialization.MapCodec;
import com.zurrtum.create.AllItemAttributeTypes;
import com.zurrtum.create.content.logistics.item.filter.attribute.ItemAttribute;
import com.zurrtum.create.content.logistics.item.filter.attribute.ItemAttributeType;
import io.netty.buffer.ByteBuf;
import org.jetbrains.annotations.NotNull;

import java.util.ArrayList;
import java.util.List;
import java.util.Optional;
import net.minecraft.class_1799;
import net.minecraft.class_1937;
import net.minecraft.class_2561;
import net.minecraft.class_8824;
import net.minecraft.class_9129;
import net.minecraft.class_9135;
import net.minecraft.class_9139;
import net.minecraft.class_9334;

public record ItemNameAttribute(String itemName) implements ItemAttribute {
    public static final MapCodec<ItemNameAttribute> CODEC = Codec.STRING.xmap(ItemNameAttribute::new, ItemNameAttribute::itemName).fieldOf("value");

    public static final class_9139<ByteBuf, ItemNameAttribute> PACKET_CODEC = class_9135.field_48554.method_56432(
        ItemNameAttribute::new,
        ItemNameAttribute::itemName
    );

    private static String extractCustomName(class_1799 stack, class_1937 level) {
        if (stack.method_57826(class_9334.field_49631)) {
            try {
                String customName = stack.method_58695(class_9334.field_49631, class_2561.method_43473()).getString();
                Optional<class_2561> component = class_8824.field_46597.parse(
                    level.method_30349()
                        .method_57093(JsonOps.INSTANCE),
                    JsonParser.parseString(customName.isEmpty() ? "\"\"" : customName)
                ).result();
                if (component.isPresent()) {
                    return component.get().getString();
                }
            } catch (JsonParseException ignored) {
            }
        }
        return "";
    }

    @Override
    public boolean appliesTo(class_1799 itemStack, class_1937 level) {
        return extractCustomName(itemStack, level).equals(itemName);
    }

    @Override
    public String getTranslationKey() {
        return "has_name";
    }

    @Override
    public Object[] getTranslationParameters() {
        return new Object[]{itemName};
    }

    @Override
    public ItemAttributeType getType() {
        return AllItemAttributeTypes.HAS_NAME;
    }

    public static class Type implements ItemAttributeType {
        @Override
        public @NotNull ItemAttribute createAttribute() {
            return new ItemNameAttribute("dummy");
        }

        @Override
        public List<ItemAttribute> getAllAttributes(class_1799 stack, class_1937 level) {
            List<ItemAttribute> list = new ArrayList<>();

            String name = extractCustomName(stack, level);
            if (!name.isEmpty()) {
                list.add(new ItemNameAttribute(name));
            }

            return list;
        }

        @Override
        public MapCodec<? extends ItemAttribute> codec() {
            return CODEC;
        }

        @Override
        public class_9139<? super class_9129, ? extends ItemAttribute> packetCodec() {
            return PACKET_CODEC;
        }
    }
}
